@@ -1,5 +1,22 @@
 from .simple_hash_connector import SimpleHashConnector
-from .sql_connectors import MsSqlConnector, MySqlConnector, SQLiteConnection, OracleSqlConnector, SnowflakeSqlConnector, MsSqlConnection, MySqlConnection, OracleSqlConnection, PostgresConnection, PostgresConnector, SnowflakeSqlConnection, SQLiteConnector
+from .sql_connectors import (
+    BaseSqlConnection,
+    BaseSqlConnector,
+    DB2Connection,
+    DB2Connector,
+    MsSqlConnection,
+    MsSqlConnector,
+    MySqlConnection,
+    MySqlConnector,
+    OracleSqlConnection,
+    OracleSqlConnector,
+    PostgresConnection,
+    PostgresConnector,
+    SQLiteConnection,
+    SQLiteConnector,
+    SnowflakeSqlConnection,
+    SnowflakeSqlConnector,
+)
 from .cql_connector import CqlConnector, CqlConnection
 from .mongo_connector import MongoConnector, MongoConnection
 from .redis_connector import RedisConnector, RedisConnection, RedisClusterConnection
@@ -7,6 +24,10 @@ from .redis_connector import RedisConnector, RedisConnection, RedisClusterConnec
 __all__ = [
     'SimpleHashConnector',
 
+    'BaseSqlConnection',
+    'BaseSqlConnector',
+    'DB2Connector',
+    'DB2Connection',
     'MsSqlConnection',
     'MsSqlConnector',
     'MySqlConnection',
